webcolors: Library for working with the color formats defined by HTML and CSS
=============================================================================

Description
-----------

Library for working with the color formats defined by HTML and CSS

License
-------

BSD-3-Clause

Upstream Contact
----------------

https://pypi.org/project/webcolors/

